The is a distribution of Org, a plain text notes and project planning
tool for Emacs.

The homepage of Org is at:
  http://orgmode.org

The installations instructions are at:
  http://orgmode.org/org.html#Installation

This distribution contains:

README
    This file.

COPYING
    The GNU General Public License.

Makefile
    The makefile to compile and install Org.  For installation
    instructions, see the manual or the more detailed procedure
    on Worg: http://orgmode.org/worg/dev/org-build-system.html

mk/
    Files needed for building Org.

lisp/
    Directory with all the Emacs Lisp files that make up Org.

doc/
    The documentation files.  org.texi is the source of the
    documentation, org.html and org.pdf are formatted versions of it.

contrib/
    A directory with third-party additions for Org.  Some really cool
    stuff is in there.

etc/
    Files needed for the ODT exporter.

testing/
    Testing suite for Org.

request-assign-future.txt
    The form that contributors have to sign and get processed with
    the FSF before contributed changes can be integrated into the Org
    core.  All files in this distribution except the contrib/ directory
    have copyright assigned to the FSF.
