This directory contains add-ons to Org-mode.

These contributions are not part of GNU Emacs or of the official Org-mode
package.  But the git repository for Org-mode is glad to provide useful way
to distribute and develop them as long as they are distributed under a free
software license.

Please put your contribution in one of these three directories:

LISP (emacs-lisp code)
======================
htmlize.el               --- Convert buffer text and decorations to HTML
org2rem.el               --- Convert org appointments into reminders
org-annotate-file.el     --- Annotate a file with org syntax
org-bookmark.el          --- Links to bookmarks
org-checklist.el         --- org functions for checklist handling
org-choose.el            --- Use TODO keywords to mark decision states
org-collector.el         --- Collect properties into tables
org-contacts             --- Contacts management
org-contribdir.el        --- Dummy file to mark the org contrib Lisp directory
org-depend.el            --- TODO dependencies for Org-mode
org-drill.el             --- Self-testing with org-learn
org-depend.el            --- TODO dependencies for Org-mode
org-elisp-symbol.el      --- Org links to emacs-lisp symbols
org-eshell.el            --- Support for links to working directories in eshell
org-eval.el              --- The <lisp> tag, adapted from Muse
org-eval-light.el        --- Evaluate in-buffer code on demand
org-exp-bibtex.el        --- Export citations to LaTeX and HTML
org-expiry.el 	         --- Expiry mechanism for Org entries
org-export-generic.el    --- Export framework for configurable backends
org-git-link.el          --- Provide org links to specific file version
org-interactive-query.el --- Interactive modification of tags query
org-invoice.el           --- Help manage client invoices in OrgMode
org-jira.el              --- Add a jira:ticket protocol to Org
org-learn.el             --- SuperMemo's incremental learning algorithm
org-lparse.el            --- Library for building custom exporters
org-mac-iCal.el          --- Imports events from iCal.app to the Emacs diary
org-mac-link-grabber.el  --- Grab links and URLs from various Mac applications
org-mairix.el 	         --- Hook mairix search into Org for different MUAs
org-man.el 	         --- Support for links to manpages in Org-mode
org-mime.el              --- org html export for text/html MIME emails
org-mtags.el 	         --- Support for some Muse-like tags in Org-mode
org-odt.el 	         --- OpenDocumentText exporter for Org-mode
org-panel.el 	         --- Simple routines for us with bad memory
org-registry.el          --- A registry for Org links
org-screen.el            --- Visit screen sessions through Org-mode links
org-secretary.el         --- Team management with org-mode
org-special-blocks.el    --- Turn blocks into LaTeX envs and HTML divs
orgtbl-sqlinsert.el      --- Convert Org-mode tables to SQL insertions
org-toc.el 	         --- Table of contents for Org-mode buffer
org-track.el             --- Keep up with Org development
org-velocity.el          --- something like Notational Velocity for Org
org-wikinodes            --- CamelCase wiki-like links for Org


PACKAGES
========

SCRIPTS (shell, bash, etc.)
===========================

dir2org.zsh          --- Org compatible fs structure output
org2hpda	     --- Generate hipster pda style printouts from Org-mode
ditaa.jar            --- ASCII to PNG converter by Stathis Sideris, GPL
